Learn R Programming

sprm (version 1.1)

predict.prm: Predict method for models of class prm

Description

Predictions from a partial robust M regression model.

Usage

## S3 method for class 'prm':
predict(object, newdata, ...)

Arguments

object
object of class prm.
newdata
optional data frame with new observations.
...
further arguments. Currently not used.

Value

  • predict.sprm returns a vector of the predicted response.

Details

If newdata is specified the sprm model is used to predict the fitted values for this data set, otherwise the fitted values of the model are returned.

References

Sven Serneels et al. (2014) Sparse partial robust M regression

Serneels, S., Croux, C., Filzmoser, P., Van Espen, P.J., Partial Robust M-Regression. Chemometrics and Intelligent Laboratory Systems, 79 (2005), 55-64.

See Also

prms, prmsCV

Examples

Run this code
set.seed(5023)
U <- c(rep(2,20), rep(5,30))
X <- replicate(6, U+rnorm(50))
beta <- c(rep(1, 3), rep(-1,3))
e <- c(rnorm(45,0,1.5),rnorm(5,-20,1))
y <- X%*%beta + e
d <- as.data.frame(X)
d$y <- y
mod <- prms(y~., data=d, a=2, fun="Hampel")

dnew <- as.data.frame(replicate(6, U+rnorm(10)))
ynewp <- predict(mod, newdata=dnew)

Run the code above in your browser using DataLab